@@ -2,6 +2,7 @@
 Tests for the tasks defined in this repo
 """
 import logging
+from dataclasses import asdict
 from dataclasses import dataclass
 from datetime import datetime
 from random import randint
@@ -60,14 +61,14 @@ class FakeGQLClient:
 
 
 @dataclass
-class FakeConstants:
-    num_dsps_repeats: int = 2
-    instrument: str = "TEST"
-    average_cadence: float = 10.0
-    minimum_cadence: float = 10.0
-    maximum_cadence: float = 10.0
-    variance_cadence: float = 0.0
-    stokes_params: Tuple[str] = (
+class FakeConstantDb:
+    NUM_DSPS_REPEATS: int = 2
+    INSTRUMENT: str = "TEST"
+    AVERAGE_CADENCE: float = 10.0
+    MINIMUM_CADENCE: float = 10.0
+    MAXIMUM_CADENCE: float = 10.0
+    VARIANCE_CADENCE: float = 0.0
+    STOKES_PARAMS: Tuple[str] = (
         "I",
         "Q",
         "U",
@@ -129,7 +130,7 @@ def generate_calibrated_data_task(tmp_path, recipe_run_id):
         yield task, number_of_frames
         # teardown
         task.scratch.purge()
-        task._constants_db.purge()
+        task.constants._purge()
     # disconnect
 
 
@@ -222,15 +223,19 @@ def write_l1_task(complete_common_header, request):
                 hdu_list=hdul,
                 tags=[Tag.calibrated(), Tag.frame(), Tag.stokes(stokes_params[i])],
             )
-        task.constants = FakeConstants(
-            average_cadence=10,
-            minimum_cadence=10,
-            maximum_cadence=10,
-            variance_cadence=0,
-            instrument="TEST",
+        task.constants._update(
+            asdict(
+                FakeConstantDb(
+                    AVERAGE_CADENCE=10,
+                    MINIMUM_CADENCE=10,
+                    MAXIMUM_CADENCE=10,
+                    VARIANCE_CADENCE=0,
+                    INSTRUMENT="TEST",
+                )
+            )
         )
         yield task, num_of_stokes_params
-        task._constants_db.purge()
+        task.constants._purge()
         task.scratch.purge()
 
 
@@ -262,7 +267,9 @@ def make_movie_frames_task(tmp_path, recipe_run_id):
         task.testing_num_dsps_repeats = 10
         task.num_steps = 1
         task.num_exp_per_step = 1
-        task.constants = FakeConstants(num_dsps_repeats=task.testing_num_dsps_repeats)
+        task.constants._update(
+            asdict(FakeConstantDb(NUM_DSPS_REPEATS=task.testing_num_dsps_repeats))
+        )
         ds = S122Headers(
             array_shape=(1, 10, 10),
             num_steps=task.num_steps,
@@ -283,7 +290,7 @@ def make_movie_frames_task(tmp_path, recipe_run_id):
             )
         yield task
         task.scratch.purge()
-        task._constants_db.purge()
+        task.constants._purge()
 
 
 def test_make_movie_frames_task(make_movie_frames_task, mocker):
@@ -313,7 +320,9 @@ def assemble_test_movie_task(tmp_path, recipe_run_id):
         task.testing_num_dsps_repeats = 10
         task.num_steps = 1
         task.num_exp_per_step = 1
-        task.constants = FakeConstants(num_dsps_repeats=task.testing_num_dsps_repeats)
+        task.constants._update(
+            asdict(FakeConstantDb(NUM_DSPS_REPEATS=task.testing_num_dsps_repeats))
+        )
         ds = S122Headers(
             array_shape=(1, 10, 10),
             num_steps=task.num_steps,
@@ -334,7 +343,7 @@ def assemble_test_movie_task(tmp_path, recipe_run_id):
             )
         yield task
         task.scratch.purge()
-        task._constants_db.purge()
+        task.constants._purge()
 
 
 def test_assemble_test_movie_task(assemble_test_movie_task, mocker):
