@@ -31,7 +31,7 @@ end_to_end.add_node(task=QualityL1Metrics, upstreams=WriteL1Data)
 end_to_end.add_node(task=SubmitQuality, upstreams=QualityL1Metrics)
 end_to_end.add_node(task=MakeTestMovieFrames, upstreams=WriteL1Data)
 end_to_end.add_node(task=AssembleTestMovie, upstreams=MakeTestMovieFrames)
-end_to_end.add_node(task=AddDatasetReceiptAccount, upstreams=AssembleTestMovie)
-end_to_end.add_node(task=TransferL1Data, upstreams=[AddDatasetReceiptAccount, SubmitQuality])
+end_to_end.add_node(task=AddDatasetReceiptAccount, upstreams=[AssembleTestMovie, SubmitQuality])
+end_to_end.add_node(task=TransferL1Data, upstreams=AddDatasetReceiptAccount)
 end_to_end.add_node(task=PublishCatalogAndQualityMessages, upstreams=TransferL1Data)
 end_to_end.add_node(task=Teardown, upstreams=PublishCatalogAndQualityMessages)
